@@ -7,7 +7,7 @@ RDF::Trine::Serializer::NTriples - NTriples Serializer.
 
 =head1 VERSION
 
-This document describes RDF::Trine::Serializer::NTriples version 0.112
+This document describes RDF::Trine::Serializer::NTriples version 0.113
 
 =head1 SYNOPSIS
 
@@ -28,6 +28,7 @@ package RDF::Trine::Serializer::NTriples;
 
 use strict;
 use warnings;
+use base qw(RDF::Trine::Serializer);
 
 use URI;
 use Carp;
@@ -43,14 +44,14 @@ use RDF::Trine::Error qw(:try);
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '0.112';
+	$VERSION	= '0.113';
 }
 
 ######################################################################
 
 =item C<< new >>
 
-Returns a new 
+Returns a new N-Triples serializer object.
 
 =cut
 
