@@ -1,11 +1,10 @@
+# RDF::Trine::Serializer::NTriples::Canonical
+# -----------------------------------------------------------------------------
+
 =head1 NAME
 
 RDF::Trine::Serializer::NTriples::Canonical - Canonical representation of an RDF model
 
-=head1 VERSION
-
-This document describes RDF::Trine::Serializer::NTriples::Canonical version 0.999_02
-
 =head1 SYNOPSIS
 
   use RDF::Trine::Serializer::NTriples::Canonical;
@@ -43,9 +42,6 @@ canonical representation for digital signing).
 
 =head1 METHODS
 
-Beyond the methods documented below, this class inherits methods from the
-L<RDF::Trine::Serializer::NTriples> class.
-
 =over 4
 
 =cut
@@ -58,17 +54,14 @@ use warnings;
 
 use Carp;
 use RDF::Trine;
-use base qw(RDF::Trine::Serializer::NTriples);
+
+our @ISA = qw();
 
 ######################################################################
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '0.999_02';
-	$RDF::Trine::Serializer::serializer_names{ 'ntriples-canonical' }	= __PACKAGE__;
-# 	foreach my $type (qw(text/plain)) {
-# 		$RDF::Trine::Serializer::media_types{ $type }	= __PACKAGE__;
-# 	}
+	$VERSION	= '0.113';
 }
 
 ######################################################################
@@ -128,11 +121,11 @@ sub serialize_model_to_string {
 	while (my $ST = $stream->next) {
 		push @statements, { 'trine' => $ST };
 		
-		if ($ST->subject->isa('RDF::Trine::Node::Blank')) {
+		if ($ST->subject->is_blank) {
 			$blankNodes->{ $ST->subject->blank_identifier }->{'trine'} = $ST->subject;
 		}
 		
-		if ($ST->object->isa('RDF::Trine::Node::Blank')) {
+		if ($ST->object->is_blank) {
 			$blankNodes->{ $ST->object->blank_identifier }->{'trine'} = $ST->object;
 		}
 	}
@@ -143,9 +136,9 @@ sub serialize_model_to_string {
 		# Really need to canonicalise typed literals as per XSD.
 		
 		$st->{'lex'} = sprintf('%s %s %s',
-			($st->{'trine'}->subject->isa('RDF::Trine::Node::Blank') ? '~' : $st->{'trine'}->subject->sse),
+			($st->{'trine'}->subject->is_blank ? '~' : $st->{'trine'}->subject->sse),
 			$st->{'trine'}->predicate->sse,
-			($st->{'trine'}->object->isa('RDF::Trine::Node::Blank') ? '~' : $st->{'trine'}->object->sse)
+			($st->{'trine'}->object->is_blank ? '~' : $st->{'trine'}->object->sse)
 			);
 		$lexCounts{ $st->{'lex'} }++;
 	}
@@ -162,7 +155,7 @@ sub serialize_model_to_string {
 	foreach my $st (@statements) {
 		next unless $lexCounts{ $st->{'lex'} } == 1;
 		
-		if ($st->{'trine'}->object->isa('RDF::Trine::Node::Blank')) {
+		if ($st->{'trine'}->object->is_blank) {
 			unless (defined $blankNodes->{ $st->{'trine'}->object->blank_identifier }->{'lex'}) {
 				$blankNodes->{ $st->{'trine'}->object->blank_identifier }->{'lex'} =
 					sprintf($blankNodePattern, $genSymCounter);
@@ -172,7 +165,7 @@ sub serialize_model_to_string {
 			$st->{'lex'} =~ s/\~$/$b/;
 		}
 		
-		if ($st->{'trine'}->subject->isa('RDF::Trine::Node::Blank')) {
+		if ($st->{'trine'}->subject->is_blank) {
 			unless (defined $blankNodes->{ $st->{'trine'}->subject->blank_identifier }->{'lex'}) {
 				$blankNodes->{ $st->{'trine'}->subject->blank_identifier }->{'lex'} =
 					sprintf($blankNodePattern, $genSymCounter);
@@ -243,7 +236,7 @@ sub serialize_model_to_string {
 	}
 
 	$rv .= "\r\n"
-		if (defined($self->{'onfail'}) && (lc $self->{'onfail'} eq 'space'));
+		if lc $self->{'onfail'} eq 'space';
 	
 	foreach my $st (@otherStatements) {
 		$rv .= $st->{'lex'} . " .\r\n";
@@ -259,8 +252,7 @@ __END__
 
 =head1 BUGS
 
-Please report any bugs or feature requests to through the GitHub web interface
-at L<https://github.com/kasei/perlrdf/issues>.
+Please report any bugs to <http://rt.cpan.org/>.
 
 =head1 SEE ALSO
 
@@ -279,7 +271,7 @@ Toby Inkster, E<lt>tobyink@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2010 Toby Inkster
+Copyright (C) 2009 by Toby Inkster
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.1 or,
